Struct ZxdgImportedV2
pub struct ZxdgImportedV2 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
an imported surface handle
An xdg_imported object represents an imported reference to surface exported by some client. A client can use this interface to manipulate relationships between its own surfaces and the imported surface.
See also the Request enum for this interface.
Implementations
impl ZxdgImportedV2
impl ZxdgImportedV2
pub fn destroyed(&self)
pub fn destroyed(&self)
the imported surface handle has been destroyed
The imported surface handle has been destroyed and any relationship set up has been invalidated. This may happen for various reasons, for example if the exported surface or the exported surface handle has been destroyed, if the handle used for importing was invalid.